@@ -1,8 +1,8 @@
 # coding: utf-8
 
 import json
-
 import requests
+from datetime import timedelta
 from sentry.plugins.bases.notify import NotificationPlugin
 
 import sentry_dingding
@@ -52,14 +52,15 @@ class DingDingPlugin(NotificationPlugin):
 
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
-        
+        time = (event.datetime + timedelta(hours=8)).strftime("%Y-%m-%d %H:%M:%S")
+
         data = {
             "msgtype": "markdown",
             "markdown": {
                 "title": "线上告警",
                 "text": u"## 线上告警\n#### 项目：{projectName}\n#### 时间：{time}\n#### 等级：{level}\n#### 内容：[{message}]({url}) \n".format(
                     projectName=group.project.name,
-                    time=event.datetime.strftime("%Y-%m-%d %H:%M:%S"),
+                    time=time,
                     level=group.get_level_display(),
                     message=event.message,
                     url=group.get_absolute_url(),
